Class: Aws::OAM::Types::GetLinkInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-oam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

The ARN of the link to retrieve information for.

Returns:

  • (String)


266
267
268
269
270
271
# File 'lib/aws-sdk-oam/types.rb', line 266

class GetLinkInput < Struct.new(
  :identifier,
  :include_tags)
  SENSITIVE = []
  include Aws::Structure
end

#include_tagsBoolean

Specifies whether to include the tags associated with the link in the response. When ‘IncludeTags` is set to `true` and the caller has the required permission, `oam:ListTagsForResource`, the API will return the tags for the specified resource. If the caller doesn’t have the required permission, ‘oam:ListTagsForResource`, the API will raise an exception.

The default value is ‘false`.

Returns:

  • (Boolean)


266
267
268
269
270
271
# File 'lib/aws-sdk-oam/types.rb', line 266

class GetLinkInput < Struct.new(
  :identifier,
  :include_tags)
  SENSITIVE = []
  include Aws::Structure
end