Class: Aws::OAM::Types::GetLinkInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::OAM::Types::GetLinkInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-oam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The ARN of the link to retrieve information for.
-
#include_tags ⇒ Boolean
Specifies whether to include the tags associated with the link in the response.
Instance Attribute Details
#identifier ⇒ String
The ARN of the link to retrieve information for.
266 267 268 269 270 271 |
# File 'lib/aws-sdk-oam/types.rb', line 266 class GetLinkInput < Struct.new( :identifier, :include_tags) SENSITIVE = [] include Aws::Structure end |
#include_tags ⇒ Boolean
Specifies whether to include the tags associated with the link in the response. When ‘IncludeTags` is set to `true` and the caller has the required permission, `oam:ListTagsForResource`, the API will return the tags for the specified resource. If the caller doesn’t have the required permission, ‘oam:ListTagsForResource`, the API will raise an exception.
The default value is ‘false`.
266 267 268 269 270 271 |
# File 'lib/aws-sdk-oam/types.rb', line 266 class GetLinkInput < Struct.new( :identifier, :include_tags) SENSITIVE = [] include Aws::Structure end |